==> TripleR_1.1.7.tar.gz: TripleR/man/TripleR-package.Rd <==
\name{TripleR-package}
\alias{TripleR-package}
\alias{TripleR}
\docType{package}
\title{Triple R: A Package for Round-Robin Analyses Using R}
\description{
Social Relation Model (SRM) analyses for single or multiple round-robin groups are performed. These analyses are either based on one manifest variable, one latent construct measured by two manifest variables, two manifest variables and their bivariate relations, or bivariate relations between two latent constructs each measured by two manifest variables. Within-group t-tests for variance components are provided for single group, between-groups t-tests for multiple groups. Preliminary handling for missing values is provided.
}

\details{
For further information of usage see \code{\link{RR}} or the built in pdf document `How to use TripleR'. You can open this document either by on this link: \url{../doc/TripleR.pdf}, or you can browse all included vignettes by opening the index of the package documentation (scroll down to the very end of this page and click on `Index'; than click on `Overview of user guides and package vignettes').

If you use this package in your research, please cite it as:
Schönbrodt, F. D., Back, M. D., & Schmukle, S. C. (2012). TripleR: An R package for social relations analyses based on round-robin designs. \emph{Behavior Research Methods, 44}, 455–470. doi:10.3758/s13428-011-0150-4

}

\author{Stefan C. Schmukle, Felix D. Schönbrodt & Mitja D. Back
}
\references{
Back, M. D., Schmukle, S. C., & Egloff, B. (in press). From first sight to friendship: A longitudinal social relations analysis of stability and change in interpersonal attraction. \emph{European Journal of Personality}.

Bonito, J. A., & Kenny, D. A. (2010). The measurement of reliability of social relations components from round-robin designs. \emph{Personal Relationships, 17,} 235 - 251.

Kenny, D. A. (1994). \emph{Interpersonal perception: A social relations analysis}. New York: Guilford Press.

Lashley, B. R., & Bond, C. F., Jr. (1997). Significance testing for round robin data. \emph{Psychological Methods, 2,} 278-291.

Schönbrodt, F. D., Back, M. D., & Schmukle, S. C. (2012). TripleR: An R package for social relations analyses based on round-robin designs. \emph{Behavior Research Methods, 44}, 455–470. doi:10.3758/s13428-011-0150-4
}

\keyword{package}

==> TripleR_1.5.0.tar.gz: TripleR/man/TripleR-package.Rd <==
\name{TripleR-package}
\alias{TripleR-package}
\alias{TripleR}
\docType{package}
\title{Triple R: A Package for Round-Robin Analyses Using R}
\description{
Social Relation Model (SRM) analyses for single or multiple round-robin groups are performed. These analyses are either based on one manifest variable, one latent construct measured by two manifest variables, two manifest variables and their bivariate relations, or bivariate relations between two latent constructs each measured by two manifest variables.
}

\details{
For further information of usage see \code{\link{RR}} or the built in pdf document `How to use TripleR'. You can open this document either by on this link: \url{../doc/TripleR.pdf}, or you can browse all included vignettes by opening the index of the package documentation (scroll down to the very end of this page and click on `Index'; than click on `Overview of user guides and package vignettes').

If you use this package in your research, please cite it as:
Schönbrodt, F. D., Back, M. D., & Schmukle, S. C. (2012). TripleR: An R package for social relations analyses based on round-robin designs. \emph{Behavior Research Methods, 44}, 455–470. doi:10.3758/s13428-011-0150-4
}

\author{Felix D. Schönbrodt, Mitja D. Back, & Stefan C. Schmukle
}
\references{
Back, M. D., Schmukle, S. C., & Egloff, B. (in press). From first sight to friendship: A longitudinal social relations analysis of stability and change in interpersonal attraction. \emph{European Journal of Personality}.

Bonito, J. A., & Kenny, D. A. (2010). The measurement of reliability of social relations components from round-robin designs. \emph{Personal Relationships, 17,} 235 - 251.

Kenny, D. A. (1994). \emph{Interpersonal perception: A social relations analysis}. New York: Guilford Press.

Lashley, B. R., & Bond, C. F., Jr. (1997). Significance testing for round robin data. \emph{Psychological Methods, 2,} 278-291.

Schönbrodt, F. D., Back, M. D., & Schmukle, S. C. (2012). TripleR: An R package for social relations analyses based on round-robin designs. \emph{Behavior Research Methods, 44}, 455–470. doi:10.3758/s13428-011-0150-4
}

\keyword{package}
